package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````E14``#0````0D0```````#0`(``,
M`"@`&``7``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````G`\`
M`)P/```$`````!````$`````$````!`````0```=*0``'2D```4`````$```
M`0````!`````0````$```'Q,``!\3```!``````0```!````_(T``/R=``#\
MG0``*`(``'02```&`````!````(````,C@``#)X```R>``#0````T`````8`
M```$````!````,P!``#,`0``S`$``"@````H````!`````0```!3Y71DS`$`
M`,P!``#,`0``*````"@````$````!````%#E=&0\?P``/'\``#Q_``#T````
M]`````0````$````4>5T9```````````````````````````!@```!````!2
MY71D_(T``/R=``#\G0``!`(```0"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````8````!0```$=.50`!``'`!`````$````"``'`!```
M```````1````1P````@````(`````!`0`"5`!(`H`!`$H(8`A(`!```+(`0)
M.(`208H$"`@`````1P```$L```!/````4````%8```!7````6`````````!:
M````6P````````!<````70```%\``````````````&I_FGSJT^\.SMY'+6_%
MWQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!N^.2
M?%7#/-)GK\QFB`=PTT-%U>PS8MOM%8PES'^IG)O@IP(*:QJ>4*/@^TD`````
M`````````````````0``````````````$@````D``````````````!$```#'
M`0`````````````1````8P$`````````````$@```!```````````````!(`
M``"@`0`````````````2````&```````````````$@```!\`````````````
M`!(```#4`0`````````````2````K`$`````````````$@```/H"````````
M`````"$````H```````````````2````+@``````````````$@```#4`````
M`````````!(```#'`@`````````````2````N`(`````````````$@```!$"
M`````````````!(````\```````````````2````EP(`````````````$@``
M`$,``````````````!(```!+```````````````2````@`(`````````````
M$@```%,``````````````!(```!<```````````````@````L0(`````````
M````$@```'@``````````````!(```!]```````````````2````Y0$`````
M````````$0```)X"`````````````!(````^`@`````````````2````A```
M````````````$@```(L``````````````"`````P`@`````````````2````
M30,`````````````$@```/D"`````````````!$```!B`@`````````````2
M````Y@(`````````````$@```/`!`````````````!(```#[`@``````````
M```1````J0``````````````$@```-X"`````````````!(```!Q`0``````
M```````2````L@``````````````(@```,$``````````````!(```"I`@``
M```````````2````3@(`````````````$@```,8``````````````!(```#,
M```````````````@````BP(`````````````$@```.8``````````````!(`
M``"1`0`````````````2````ZP``````````````(`````<!````````````
M`!(```!P`@`````````````2````#0$`````````````$@```(`!````````
M`````!(````;`0`````````````2````+`$`````````````$@````P"````
M`````````!(````=`@`````````````2````,@$`````````````$@```%<"
M`````````````!(```#7`@`````````````2````00$`````````````$@``
M`,\"`````````````!(````'`@`````````````2````50$`````````````
M$@````,#`````````````!(```#X`@`````````````A````7`$`````````
M````$@```/,"``#`$P``U0$``!(`"P#!`0``$3D```$````2``P`CP,``&HB
M``"S!0``$@`+`#L$```G*@``7@```!(`"P!L`P``AAT```4````2``L`^0,`
M```0```!````$@`(`+(#```=*```"@(``!(`"P`?!```BQT``*T!```2``L`
MZ@,``"2@````````$``5`'T#``#&(0``I````!(`"P"<`P``'!P``#L````2
M``L`I`,``%$A``!*````$@`+`,@#``"0-@``^@```!(`"P#=`P``.!\``!4`
M```2``L`-@0``'"P````````$``5`#(#``"P%0``-P```!(`"P#_`P``31\`
M`*H````2``L`TP,``""@```$````$0`4`!@$```DH````````!``%`#O`P``
ME14````````0``L`]@,``#XV``!2````$@`+`#L#``";(0``*P```!(`"P!6
M`P``K!P``-H````2``L`+`0``(HW```F`0``$@`+``L$``#W'P``6@$``!(`
M"P``;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E
M96L`9V5T<&ED`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E
M9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S
M=')C:'(`7U]D97)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<F5A9&QI;FL`
M7U]C>&%?9FEN86QI>F4`97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N
M951A8FQE`')E860`7U]R96=I<W1E<E]F<F%M95]I;F9O7V)A<V5S`')M9&ER
M`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T
M7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC`'-T<FQE;@!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER
M`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!?7W-T86-K7V-H:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYM=7-L
M+7@X-BYS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!S:&%?:6YI=`!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M7V5N9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]2
M10````#$GP``"````-"?```(````V)\```@`````H```"`````2@```(````
M"*````@````,H```"````!"@```(````%*````@````@H```"````,B?```&
M`@``S)\```8#``#4GP``!A@``-R?```&'```X)\```8@``#DGP``!B<``.B?
M```&*P``[)\```8P``#PGP``!C0``/2?```&-@``^)\```8X``#\GP``!CP`
M`.B>```'`0``[)X```<$``#PG@``!P4``/2>```'!@``^)X```<'``#\G@``
M!P@```"?```'"0``!)\```<*```(GP``!PP```R?```'#0``$)\```<.```4
MGP``!P\``!B?```'$```')\```<1```@GP``!Q(``"2?```'$P``*)\```<4
M```LGP``!Q4``#"?```'%@``-)\```<7```XGP``!QD``#R?```'&@``0)\`
M``<;``!$GP``!QT``$B?```''@``3)\```<?``!0GP``!R$``%2?```'(@``
M6)\```<D``!<GP``!R4``&"?```')@``9)\```<H``!HGP``!RD``&R?```'
M*@``<)\```<L``!TGP``!RT``'B?```'+@``?)\```<O``"`GP``!S$``(2?
M```',@``B)\```<S``",GP``!S4``)"?```'-P``E)\```<Y``"8GP``!SH`
M`)R?```'.P``H)\```<]``"DGP``!SX``*B?```'/P``K)\```=```"PGP``
M!T$``+2?```'0@``N)\```=#``"\GP``!T0``,"?```'1@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.@H!P``Z,,H``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____HP0!``!FD/^C#`$``&:0
M_Z,4`0``9I```````````(U,)`2#Y/#_<?R-00A5B>575HG.4^@-`@``@<,"
MBP``48/L'%"-00104>A1_O__BX,@`0``@\0,4%#_LQP!``#HZ_S__XN#\```
M`(/$$(N[``$``(`X`'4TZ(+]__^)@Y`1``"%P'4*@^P,:@'H'O[__X/L#%#H
M=?[__UK_-^C]_O__@\00QH!W!@```(/L#/\WZ.G^__^`B,H"```"6/\WZ-K^
M__^#Q!"`B,H"```!BP:-2`.#P`2)3>0]____/W8%Z(G]__^#[`S!X`)0Z/W]
M__^+3@2+-H/$$(F#C!$``(L1B1"-D]2C__^)4`2+DT0!``")4`B-D]>C__^)
M4`RZ`0```#G6?@J+/)&)?)`,0NORNA````"%]GX'C12U#````(/L#,<$$```
M``!J`%"-@WM]____=>10_[.0$0``Z$O\__^#Q"")QH7`=1.#[`S_LY`1``#H
M5/W__X/$$(G&@^P,_[.0$0``Z,'\__^-@[FA___HU`(``(/$$(7`=3"#NX@1
M````=1&-@VZA___HN0(``(F#B!$``(N#B!$``(7`=`R#[`Q0Z+D4``"#Q!"#
M[`S_LY`1``#HX?W__^B\^O__@\00C67PB?!96UY?78UA_,,Q[8G@@^3P4%#H
M`````($$)&F(``!0Z`````!3Z#$```"!PR:)``"#[!"+1"08:@"-4`3_L_0`
M``#_L_P```!2_S#_L^@```#H'OS__X/$*%O#BQPDPV:09I"0Z(4!``"!PN>(
M``"-BD@!``"-@D@!```YR'0=BX+X````A<!T$U6)Y8/L%%'_T(/$$,G#C70F
M`)##C;0F`````.A%`0``@<*GB```58GE4XV*2`$``(V"2`$``(/L!"G(B</!
MZ!_!^P(!V-'X=!2+DA`!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:0
M58GE5^CU````@<=3B```5E.#[`R`OV0!````#X5_````BY<,`0``A=)T$X/L
M#/^W)`$``(G[Z.W\__^#Q!"-MRC___^-GRS___^+AV@!```I\\'[`H/K`3G8
M<QJ-="8`@\`!B8=H`0``_Q2&BX=H`0``.=ARZNCU_O__BX<$`0``A<!T%(/L
M#(V'I.'__XG[4.B*_/__@\00QH=D`0```8UE]%M>7UW#C;0F`````)!5Z```
M``!:@<*FAP``B>53Z*+^__^!PY>'``"#[`2+@Q0!``"%P'09C8-L`0``4FH`
M4(V#I.'__U#H0OS__X/$$(M=_,GIMO[__XL4),.+/"3#55=6,?93Z%K^__^!
MPT^'``"#[!R)5"0$A<!T9HG!BX,(`0``,?:)S8L0A=)T5(I%`(3`=`<\/70#
M1>OR*<V)UXLWA?9T/(E4)`Q055&)3"045NAG^?__@\00BTPD"(M4)`R%P'47
M@#PN/741BT0D!"G7C70N`<'_`HDXZP6#QP3KOH/$'(GP6UY?7<.#[!QEBQ44
M````B50D##'2C50D".A;____BU0D#&4K%10```!T!>A[(```@\0<P^@X____
M@<*:A@``5E.)PX/L%&6A%````(E$)`PQP(NR"`$``(U4)`B)V.@6____A<!T
M%XL&BU0D"(T$D(M0!(D0A=)TWX/`!.ORBT0D#&4K!10```!T!>@;(```@\04
M6U[#55>)QU93Z#W]__^!PS*&``"![+P```!EH10```")A"2L````,<"%_P^$
M!@$``(`_``^$_0```(/L#%?H4??__XE$)!2#Q!"%P`^$Y0```(V#):'__XE$
M)`B-@R2A__^)1"0,@^P,_W0D$.C2]___@\00A<`/A*,```"-<!-24O]T)!!6
MZ*CW__^#Q!"%P'334%#_="045NB5]___@\00A<!TP(/L#%?H)?K__XDT)(G%
MZ!OZ__^-1`4"B00DZ+_W__]6B<6-@R>A__]74%7HWOG__X/$&(U$)"105>A0
M^?__@\000'09BT0D+"4`\```/0!```!U"8GHZ`+____K#(/L#%7H:/?__X/$
M$(/L#%7H3/G__X/$$.E&____@^P,_W0D$.B8]___B3PDZ/#X__^#Q!"+A"2L
M````92L%%````'0%Z,P>``"!Q+P```!;7E]=PU:)QE/HZ_O__X'#X(0``('L
MK````&6A%````(F$)*0````QP(U$)!105NCN^/__@\00A<!U,8M4)!R!X@#P
M``"!^@!```!T"('Z`*```'494%!J`E;H(_;__X/$$(7`#Y3`#[;`ZP(QP(N4
M))P```!E*Q44````=`7H0QX``('$I````%M>PU575HG64^AB^___@<-7A```
M@^PLB40D!&6A%````(E$)!PQP(`Z/74!1H/L#%;HP_C__X/$$(E$)`B+1"0$
MC50D&.C!_/__B<>%P'0H@^P,4.B@^/__@\00.40D"`^'K0```#'`BA0&B!0'
M0(32=?7I$P$``(N#"`$``#'_BPB#/+D`=`-'Z_>#NX01````C2R]"````'0=
M4E)54>@U]?__BY,(`0``@\00B0*%P'5,Z=,```")3"0,@^P,5<>#A!$```$`
M``#HVO7__X/$$(G"A<`/A*\```!0C47X4(M,)!114HE4)!SHR?7__XM4)!R+
M@P@!``"#Q!")$(N#"`$``(E\)!B+`,=$*/P`````BT0D!(H0A-)T"(#Z/70#
M0.ORBZL(`0``BWPD&(/L#(M5`(T4NHE4)!B+3"04*T0D$(U$`0)0Z%OU__^+
M5"0<@\00B0*%P'0PBT4`BP2X_T0D!(M\)`2)P4"*5_^(4/^$TG0%@/H]=>;&
M`3TQTHH,%H@,$$*$R77UBT0D'&4K!10```!T!>B@'```@\0L6UY?7<-3Z,7Y
M__^!P[J"``"#[!2+@P`!``#_,.@(]___C9-4X/__4HV3+:'___^S&`$``%)0
MZ,[V__^#Q"A;PU93Z(GY__^!PWZ"``"#[!"+LP`!``#_-NC,]O__B00DZ*#_
M__]8_S;HO/;__UE>:@")PHV#TZ/__U!0C8-!B?__4(V#2:'__U!2Z.KS__^#
MQ"1;7L-55U93Z#+Y__^!PR>"``"![!P@``!EH10```")A"0,(```,<#HZ_/_
M_X/L#(V37J'__U)0C8-BH?__4&@!$```C6PD)E7HBO/__X/$((U0`8'Z`1``
M`'8"#PM`=00QP.M94&@`$```C;0D$Q```%95Z/_T__^#Q!")Q87`>-^#[`R-
M0`%0Z.KS__^#Q!"%P'3,.?!S!XT4*#G6<KPY\'8'C10N.=!RL8']`1```'^I
M_(G'B>GSI,8$*`"+E"0,(```92L5%````'0%Z#D;``"!Q!P@``!;7E]=P^DA
M____55=64^A3^/__@<-(@0``@>R\$```9:$4````B80DK!```#'`B[0DT!``
M`(N\)-00``"-@VZA___H1OK__XD$)%55:B]6Z.OS__^#Q!"%P'02B?*-@W>A
M___HD?S__^DH`0``@^P,C:N$H?__5NAS]?__B3PDB40D%.AG\___6EE54.@>
M]?__@\00B<>-@R6A__^)1"0(C8.&H?__B40D#(7_=*V`/P!U!(M\)`B#/"0`
M=!=04%?_="0,Z(;R__^#Q!"%P`^$K0```(/L#%?H$O7__X/$$(!\!_\O=0=(
MQ@0'`.ORBTPD!(U$"`$]_P\```^/6O___U!0C8-UHO__5O]T)!A74&@`$```
MC;PDR````%?HW?'__X/$($`]`!```'8"#PM148U$)"105^@3]/__@\00A<!U
M/HM$)"PE`/```#T`@```=2Y24FH!5^B2\?__@\00A<!U'8GZC8-WH?__Z(C[
M__^#[`Q7Z'7R__^#Q!")QNL44%!5:@#H)/3__X/$$(G'Z17___^+A"2L$```
M92L%%````'0%Z(D9``"!Q+P0``")\%M>7UW#BU0D!(G0B@J$R70(0H#Y+W7T
MZ_##5E-3BW0D$.B.]O__@<.#?P``A?9T.(`^`'0S@^P,5NC_\___@\00C40&
M_SG&<Q:`."]U#4CK](`X+XU0_W0SB=`YQG+R.<9U*8`^+W4+@^P,C8,EH?__
MZPF#[`R-@X:A__]0Z+OQ__^#Q!#K.8`X+W4%2#G&<O8I\(U0`H'Z`!```'<@
M0#T`$```=@(/"U%05HVSA`$``%;H1O+__X/$$(GPZP(QP%I;7L-5N2(```!7
M5E/HXO7__X'#UWX``(/L3&6A%````(E$)#PQP(U\)!J-LS#@___\\Z2-@XBA
M__^-NVZA___H!?C__XV#D:'__XVSQ:'__^CT]___C8.9H?__C:O/H?__Z./W
M__^-@Z*A___HV/?__XV#J:'__XE$)`SHR??__XV#N:'__^B^]___B?CHM_?_
M_XGPZ+#W__^)Z.BI]___C8/9H?__Z)[W__^-@W>A___HD_?__XV#XZ'__^A9
M]___A<!T"8G"B>CHN/G__XV#]*'__^A!]___B<*%P'0+C8,&HO__Z)SY__^-
M@Q&B___H)??__XG"B?B%TG4RC8,AHO__Z!+W__^)PH7`=1]0C8,RHO__:@I0
MC40D-U#H*O#__X/$$(7`=0N-5"0UB?#H4OG__XM$)`R-DSVB___H0_G__XM$
M)#QE*P44````=`7H:Q<``(/$3%M>7UW#4^B0]/__@<.%?0``@^P(@[M``0``
M_W4GC8/%H?__Z)KV__\QTH7`=!"*`#PP#Y7!,=*$P`^5PB'*B9-``0``BX-`
M`0``@\0(6\-3Z$;T__^!PSM]``"#[`CHX?'__X/L#%#H*/#__X/$$(7`=`*+
M`(/$"%O#55=64^@8]/__@<,-?0``@^P<BVPD,(V#/Z+__XE$)`CH(_;__X7`
M=`>`.`")QG4+BT0D"(GJ@\0<ZUA04%56Z(;O__^#Q!"%P'51@^P,5>A6\?__
MB30DB<?H3/'__XU$!P*)!"3H\.[__XDT)(G"C8.$H?__4(V#=:+__U504HE4
M)"SH`O'__XM4)"R+1"0H@\0\6UY?7>D8^/__@\0<6UY?7<-5N08```!75E/H
M;_/__X'#9'P``('L+($``(N$)$"!``"-O"3$````B40D"(VS*`$``&6A%```
M`(F$)!R!```QP(V#5J+__\>$)+0`````````B80DK````(V#):'__XF$)+``
M``#\\Z6-@UNB___'A"3``````````(F$)+@```"-@V"B__^)A"2\````C8-N
MH?__Z`OU__^%P'0A@#@`B<9T&H/L#%#HK_[__XDT).A1[O__B40D$.G/!```
MZ&[^__^-O"2X````B<:%P'4SBP>%P'0GZ,GT__^%P'4%@\<$Z^R`.`!T]H/L
M#%#H%.[__X/$$(G&A<!TY.L&C;-/HO__@^P,5NCZ[___C40``8D$).B>[?__
M@\00C9-IHO__B<>)Q0^V!H3`=!E11E!2B50D#%6#Q0+HJ>___X/$$(L4).O@
MC;0DQ````(LNA>UT*8GHZ$OT__^)Q87`="6`.`!T(.@@]O__A<!T%X/L#%7H
MD.W__X/$$(G%C;0DK````.LR@\8$Z\.+%H72="N`.@!T)HG0B10DZ.OU__^+
M%"2%P'0.@^P,4NA8[?__@\00B<6#Q@2%[73/@^P,5>A#[___B3PDB<;H.>__
M_XVT!@0$``")-"3HVNS__XE$)!18C8-NHO__6E=0C8.&H?__B40D'%"-@W.B
M__]54/]T)"#HX.[__X/$&&C``0``_W0D$.AO[O__@\000'4SZ%3N__^+`(/X
M$70G@^P,4/]T)!2+1"0<_S"-@WRB__]0BX/L````_S#HJ^W__X/$(.LZ5U>-
M1"0D4/]T)!#H1N[__X/$$(G%A<!T+?]T)`2+1"0,_S"-@[>B__]0BX/L````
M_S#H;^W__X/$$,<$)`````#I^@(``(M$)"PE`/```#T`0```=<.+?"0TZ'?N
M__\YQW6VBT0D+"7_`0``/<`!``!UIH/L#%;HZNO__XE$)!"-@TJB___HR?+_
M_X/$$(7`=0B+1"0(BS#K%U964(M$)!3_,.@I^/__@\00B<:%P'3A@^P,5NC\
M[?__@\00B<>#^`-V7HV#"J/__U%14(U$/OQ0Z#_K__^#Q!"%P'5$@_\$=`>`
M?#[[+W4XBT0D"(MX!(7_="V#[`Q7Z+CM__^#Q!"#^`-V'(U$!_Q24HV3#Z/_
M_U)0Z/WJ__^#Q!"%P'4"B?[H</O__XG'A<`/A64!``!04&H`5NB+Z___@\00
MB<:%P`^$3@$``&H":O]J[E#HHNK__X/$#&H&C:PD)`$``%56Z'_L__^#Q!"`
MO"0<`0```'5=@+PD'0$``$-U4X"\)!X!``!!=4F`O"0?`0``0W4_@+PD(`$`
M`$AU-8"\)"$!``!%=2MJ`FK_:L96Z$3J__^#Q`QJ*556Z"CL__^-@].C__]>
M7U!5_W0D'.FI````:@!J`&H`5N@9ZO__Z*(/``")Q8/$$%%H`(```(V4)"0!
M``!2B50D%%;HY^O__X/$$(M4)`B%P'X+45!25>C##P``Z\^#[`Q6Z*CK__]8
M6E6-M"3K````5NBB$```@\00C9-IHO__50^V!#Y0C00_1U*-K"3_````B50D
M%`'H4.A![/__@\00@_\4BU0D"'76C8/3H___QH0D&P$```!75U"-@X:A__]5
M4(V#%*/___]T)!A0_W0D'.@([/__@\0@Z8(```"-DSVB__^-@\6A___H&?/_
M_XV[,:/__^A4Z?__5E:-L].C__]64(V#(Z/___]T)!S_="084/]T)!SHPNO_
M_X/$(%)2:,`!``#_="0,Z$_K__^#Q!!`=2OH-.O__X,X$74AZ`KI__]%4595
M4/]T)!S_="085_]T)!SH@^O__X/$(.N_@^P,_W0D$.@BZ___BU0D$(V#;J'_
M_^B-\O__6/]T)`SHS_G__X/$$(N$)!R!``!E*P44````=`7HI1```(L$)('$
M+($``%M>7UW#55=64^C![?__@<.V=@``@^P8B[,``0``_S;H!.O__UG_-HG'
MZ/KJ__^*5V2(4&6-@ZFA___HM^___X/$$(7`=`N`.#%U!H!X`0!T!>B)]___
M@^P,_S;HR.K__XV33J/__VH#:@%24.@GZ?__@\0@B<>%P'1$BT`,@^P,BRC_
M-NB?ZO__@\0,C9-0H___4E50Z![I__^+1PR#Q!"+./9'"D!T%H/L#/\VZ';J
M__]=6E=0Z"WH__^#Q!"#[`S_-NA@ZO__C9-5H___:@-J`5)0Z+_H__^#Q"")
MQ87`=&>-@W>A___H">___XG'A<!T!8M%#.LWZ)?S__^%P(G'BT4,="&#[`R+
M*/\VZ!;J__^#Q`Q755#HF^C__XD\).C#Z?__ZQ^+DXP1``"+.HLH@^P,_S;H
M[>G__X/$#%=54.ARZ/__@\00@^P,_S;HU>G__X/$#(V35Z/__VH!4E#HX^;_
M_UK_-HG'Z+GI__^#Q`R-DVRC__]25U#H..C__UG_-NB@Z?__QD!E`(V#;J'_
M_^A?[O__@\00B8.($0``A<!U)H/L#/^SC!$``.B@^/__@\00B8.($0``A<!U
M"X/L#(V#<J/__^LW4%!HP`$``/^SB!$``.C\Z/__@\00C5`!@_H!=B"#^!%T
M&U"+@XP1``#_LX@1``#_,(V#DZ/__U#H@>;__X/$#%M>7UW#5U93BW0D$.BT
MZ___@<.I=```@^P,5N@+]?__B00DZ.[T__^#Q!")Q^C]]O__A<!T*87V="6`
M/@!T(%!0C8-NHO__4%?H(.?__X/$$#G'=0I;B?!>7^D>[O__6UY?PU4QTE=6
M4X'L?`$``(E$)`AEH10```")A"1L`0``,<"+1"0(BTR0'(U$)"P/R8D,D$*#
M^A!UZ8V,)"P!``"+4#0S4""#P`0S4`0S4/S1PHE0/#G(=>B+1"0(BTPD,(L`
MB40D$(M$)`B+0`2)1"08BT0D"(M`"(E$)`R+1"0(BU0D#(ML)`R+0`R)1"04
MBT0D"(M<)!2+0!"-O`N9>8):BTPD$(M<)#2)1"0<BT0D+(MT)!S!R0*-G!V9
M>8):BVPD.(VT!IEY@EJ+1"00P<`%`<:+1"0,,T0D%"-$)!@S1"04`<:+1"08
MP<@",<(C5"00,U0D#`'7B?+!P@4!UXG",<HA\L'.`C'"C80HF7F"6HML)#P!
MTXGZP<(%`=.)RC'R(?K!SP(QRHV,*9EY@EJ)_0'0B=K!P@4!T(GR,?HAVC'R
M`=&)PL'"!<'+`@'1,=V+5"1`(<7!R`(Q_8V4%IEY@EJ)S@'JP<8%B=T!\C'%
MB<:+1"1$(<TQW8V$!YEY@EJ)UP'HP<<%B?4!^(G/BTPD2,'/`C']C8P+F7F"
M6HG#(=7!PP4Q]0'IB?T!V8G3BU0D3,'+`C'=C906F7F"6HG.(<7!Q@4Q_<'(
M`@'JB=T!\C'%B<:+1"10(<TQW8V$!YEY@EJ)UP'HP<<%B?4!^(G/BTPD5,'/
M`C']C8P+F7F"6HG#(=7!PP4Q]0'IB?T!V8G3BU0D6,'+`C'=C906F7F"6HG.
M(<7!Q@4Q_<'(`@'JB=T!\C'%B<:+1"1<(<TQW8V$!YEY@EJ)UP'HP<<%B?4!
M^(G/BTPD8,'/`C']C8P+F7F"6HG#(=7!PP4Q]0'IB?T!V8G3BU0D9,'+`C'=
MC906F7F"6HG.(<7!Q@4Q_<'(`@'JB=T!\C'%B<:+1"1H(<W!R0(QW8V$!YEY
M@EJ)UP'HP<<%B?4!^#'-BWPD;"'5P<H",?6-O#N9>8):B<,![\'#!8ML)'`!
MWXG+,=.-M"Z9>8):B=4AP\'(`C'+,<4!WHG[(?W!PP4!WHM<)'0QU<'/`HV<
M&9EY@EJ)\0'KP<$%B<4!RS']BTPD>"'UP<X",<6-C`J9>8):B=H!Z<'"!0'1
MBU0D?(V$$*'KV6Z)^C'R,=K!RP(!PHG(P<`%`<*+A"2`````C;P'H>O9;HGP
M,=@QR`'XB=?!QP4!^(G/BXPDA````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%
M`?&)UHN4)(@```#!S@*-G!.AZ]ENB?HQ\C'"`=J)R\'(`L'#!0':B<.+A"2,
M````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDD````,'/`HVT#J'KV6Z)
MV3'Y,=$!\8G&P<8%`?&)UHN4))0```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)
MR\'#!0':B<.+A"28````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDG```
M`,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)*````#!S@*-G!.AZ]EN
MB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2D````C;P'H>O9;HGP,=@QR`'XB=?!
MQP4!^(G/BXPDJ````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)*P`
M``#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2P````C;P'H>O9
M;HGP,=@QR`'XB=?!QP4!^(G/BXPDM````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&
MP<8%`?&)UHN4)+@```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+
MA"2\````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDP````,'/`HVT#J'K
MV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4),0```#!S@*-G!.AZ]ENB?HQ\C'"P<@"
MB<4!VHN$),@```")R\'#!0':C9P'H>O9;HGPB>\QZ#'(`=B)T\')`L'#!2'/
M`=B)ZPG+(=/!R@()WXN<),P```"-G![<O!N/B<8!^\'&!8G/`?,)UXG.(<<A
MUL'(`@G^B[PDT````(V\/=R\&X^)U0'WB=XAQ<'&!0'WB=8)QB'>P<L""?6+
MM"34````C;0QW+P;CXGY`>[!P06)W8G#`<X)ZXG!(?LAZ0G9BYPDV````(V<
M&MR\&X^)\@'+P<\"B>G!P@4)^0'3B>HA\<'.`B'Z"<J+C"3<````C8P(W+P;
MCXG8`='!P`6)^@'!"?*)^"':(?#!RP()T(N4).````"-E!7<O!N/B?4!PHG(
M(=W!P`4!PHGP"=@AR`G%BX0DY````(V$!]R\&X^)UP'HP<<%B=T!^(G/B=G!
MSP()^2'](=$)S8N,).@```"-C`[<O!N/B<8!Z<'&!8G]`?&)UHGZP<X""?(A
M]2'"P<@""=6+E"3L````C903W+P;CXG+`>K!PP6)]0':B<.)\`G8(=TAR`G%
MBX0D\````(V$!]R\&X^)UP'HP<<%B=T!^(G/B=G!SP()^2'](=$)S8N,)/0`
M``"-C`[<O!N/B<8!Z<'&!8G]`?&)UHGZP<X""?(A]2'""=6+E"3X````C903
MW+P;CXG+`>K!PP6)]<'(`@':B<.)\`G8(=TAR`G%BX0D_````(V$!]R\&X^)
MUP'HP<<%B=T!^(G/B=G!SP()^2'](=$)S8N,)``!``"-C`[<O!N/B<8!Z<'&
M!8G]`?&)UHGZP<X""?(A]2'"P<@""=6+E"0$`0``C903W+P;CXG+`>K!PP6)
MQ8GP`=H)Z(GS(<@AZPG#BX0D"`$``(V$!]R\&X^)[P'8B=/!R0+!PP4ASP'8
MB>L)RR'3P<H""=^+G"0,`0``C9P>W+P;CXG&`?O!Q@6)SP'SB<XAUPG6(<;!
MR`()]XNT)!`!``"-M#7<O!N/B=4!_HG?"<7!QP4AW<'+`@'^B=<AQPGOBZPD
M%`$``(V,*=R\&X^)Q0'YB?<)W<''!2'U`?F)QR'?">^+K"08`0``C90JW+P;
MCP'7B<K!S@+!P@4!UXN4)!P!``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0
MBY0D(`$``(V<$];!8LJ)\C'*,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%B
MRHG+,?LQP\'(`@'SB=;!Q@4!\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9
MP<$%`<B)T8N4)"P!``#!R0*-E!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$`
M`,'+`HVT%M;!8LJ)RC':,<+!R`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*
MB=DQ\3'YP<\"`<&)T,'`!0'!BX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%
M`=B)TXN4)#P!``"+;"00P<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4
M)$`!``"-O!?6P6+*B=HQRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%B
MRHG+,?LQ\\'.`@'#B=#!P`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!
M!0'(B=&+E"1,`0``P<D"C907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!
M``"-M!;6P6+*B<HQVC'"P<@"`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9
M,?$Q^<'/`@'!B=#!P`4!P8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8
MB=.+E"1<`0``P<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-
MO!?6P6+*B=HQRC'"P<@"`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!
MS@(!^XG7P<<%`?N+O"1H`0``C;P]UL%BR@'/B<$#1"0<,?$QT<'*`@-4)`P!
M^8G?P<<%`?F+?"0(B0^+3"08B5<(`=F)1Q")3P2+3"04C10QB5<,BX0D;`$`
M`&4K!10```!T!>B!`@``@<1\`0``6UY?7<-3Z*/?__^!PYAH``"#[!1J8.C,
MVO__QP`!(T5GQT`$B:O-[\=`"/[<NIC'0`QV5#(0QT`0\.'2P\=`%`````#'
M0!@`````QT!<`````(/$&%O#55=64X/L'(ML)#B+7"0PBW0D-(T$[0`````#
M0Q1S`_]#&(E#%(M+7(GHP>@=`4,8C4,<B40D"(7)=%.X0````"G(.>A^`HGH
MBU0D"`'*.?)S"HT,`CG.<P/\#PN-/`:)?"0,.?)V!#GZ<N[\B=>)P2G%\Z2+
M2UP!P8E+7(/Y0'5QB=CH;?/__XMT)`SK`?R#_3]^,#MT)`AV!XU#7#G&<KF-
M1D")1"0,.70D"'8&.40D"'*FBWPD"+D0````@^U`\Z7KO3MT)`AV"HM$)`@!
MZ#G&<H8[="0(<PV-!"XY1"0(#X)S____BWPD"(GI\Z2):UR#Q!Q;7E]=P^@A
M`0``!4UG``!55U93@^P<BUPD-(MT)#")1"0$BT,4BU,8B<7!Z`,/RHE4)`B#
MX#^-4QP/S8UX`8D4),9$`QR``?J#_SA^*;E`````*?G\,<")U_.JB=B)3"0,
MZ)KR__^+/"2+1"0,N0X```#SJ^L.N3@````I^?PQP(G7\ZJ+1"0(B6M8B4-4
MB=CH:_+__XL#@^P,P>@8B`:+`\'H$(A&`8L#B&8"BP.(1@,/MD,'B$8$#[=#
M!HA&!8M#!(AF!HM#!(A&!P^V0PN(1@@/MT,*B$8)BT,(B&8*BT,(B$8+#[9#
M#XA&#`^W0PZ(1@V+0PR(9@Z+0PR(1@\/MD,3B$80#[=#$HA&$8M#$(AF$HM#
M$(A&$U.+7"04Z%C:__^#Q"Q;7E]=PXL$),-3Z"W=__^!PR)F``"#[`CHN-K_
M_X/$"%O#9I"0Z*7>__^!P@=F``"+@B#___^#^/]T*E6)Y5.-FB#___^#[`2-
M="8`D/_0BT/\@^L$@_C_=?.+7?S)PXVV`````,.#[`SH9]W__X/$#,,`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``
M55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`
M+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,`5$5-4$1)4@!435``&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)
M3TX`,2XP-30`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A
M<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@7T9(.PIM>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N
M:U]S:7IE.R`C($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(
M+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T
M85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^
M.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG
M97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT
M*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#
M86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM
M?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P````$;`SOP````
M'0```.20__\,`0``9)3__S`!``"$E/__W`L``$:8__]$`0``TIC__Y`!```!
MF?__J`$``&.9___4`0``MYK__YP"```^F___Z`(``."<__]H`P``&YW__Y@#
M``!PG?__Y`,``$J>__]@!```3Y[__W0$``#\G___;`4``!&@__^`!0``NZ#_
M_]`%```5HO__'`8``%^B__\\!@``BJ+__V@&```NH___Z`8``.&H__]H"@``
MZZK__X@+``!)J___)`P```*W__]D#```5+?__X@,``!.N/__Q`P``'2Y__\(
M#0``>+G__QP-```4``````````%Z4@`!?`@!&PP$!(@!```@````'````-"/
M__^``P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````"R3__\8````````
M`$@```!4````^I;__XP`````00X(A0)!#@R'`T$.$(8$0PX4@P5.#C!W#C1!
M#CA!#CQ%#D!(#C!K#A1#PPX00<8.#$''#@A!Q0X$```4````H````#J7__\O
M`````$,.(&L.!``H````N````%&7__]B`````$P."(8"00X,@P-%#B`"30X,
M0<,."$'&#@0``,0```#D````AY?__U0!````00X(A0)!#@R'`T,.$(8$00X4
M@P51#M`!8P[<`4$.X`%,#M`!7P[<`40.X`%(#M`!3`[4`4$.V`%$#MP!00[@
M`4@.T`%%#M0!00[8`40.W`%!#N`!2`[0`4<.W`%!#N`!7`[D`4D.Z`%!#NP!
M00[P`4@.V`%%#MP!00[@`4@.T`%?#MP!00[@`4@.T`%##MP!00[@`4@.T`%(
M#MP!1`[@`5`.T`%;#A1!PPX00<8.#$''#@A!Q0X$2````*P!```3F/__AP``
M``!!#@B&`D,.#(,#40ZX`50.O`%!#L`!2`ZP`5\.M`%!#K@!0@Z\`4$.P`%(
M#K`!9PX,0<,."$'&#@0``'P```#X`0``3IC__Z(!````00X(A0)!#@R'`T$.
M$(8$0PX4@P5.#D!9#DQ!#E!(#D!:#DQ!#E!(#D`"0`Y$00Y(00Y,00Y03@Y`
M4@Y,00Y04@Y`2PY$1`Y(10Y,00Y05@Y`=0Y,5PY03`Y``DL.%$'##A!!Q@X,
M0<<."$'%#@0`+````'@"``!PF?__.P````!!#@B#`DX.'$@.($P.)$P.*$$.
M+$$.,$@."$'##@0`2````*@"``![F?__50````!!#@B&`D$.#(,#3@X<2`X@
M3@X<0@X@1@X<00X80@X<20X@00XD1PXH1PXL00XP2`X,0<,."$'&#@0``'@`
M``#T`@``A)G__]H`````00X(A0)!#@R'`T$.$(8$00X4@P51#K!`5PZ\0$<.
MP$!!#L1`1P[(0$4.S$!%#M!`2`ZP0%4.M$!%#KA`2`Z\0$$.P$!(#K!`20Z\
M0$0.P$!(#K!``D@.%$'##A!!Q@X,0<<."$'%#@0````0````<`,``.*9__\%
M`````````/0```"$`P``TYG__ZT!````00X(A0)!#@R'`T$.$(8$00X4@P51
M#M`A;`[4(4$.V"%"#MPA00[@(4@.T"%9#MPA1P[@(5(.W"%!#M@A00[<(4$.
MX"%(#M`A:@[4(4$.V"%!#MPA1`[@(4@.T"%+#MPA00[@(4@.T"%B#M0A00[8
M(4<.W"%$#N`A00[D(4$.Z"%%#NPA2`[P(4@.T"%+#M0A00[8(44.W"%!#N`A
M2`[0(54.U"%!#M@A0@[<(4$.X"%(#M`A5`[<(4$.X"%(#M`A10[4(4$.V"%!
M#MPA0@[@(4@.T"%B#A1#PPX00<8.#$''#@A!Q0X$$````'P$``"(FO__%0``
M``````!,````D`0``(F:__^J`````$$."(8"00X,@P-!#A!;#AQ!#B!(#A!J
M"@X<2`M##AQ'#B!(#A!D#A1!#AA!#AQ'#B!(#A!'#@Q!PPX(0<8.!$@```#@
M!```XYK__UH!````00X(A0)&#@R'`T$.$(8$00X4@P5.#F`"]0YD2`YH00YL
M10YP2`Y@<PX40<,.$$'&#@Q!QPX(0<4.!``<````+`4``/&;__]*`````$$.
M"(,"3@X0>0X(0<,.!"@```!,!0``&YS__RL`````00X(@P).#A!(#AQ!#B!(
M#A!)#@A!PPX$````?````'@%```:G/__I`````!!#@B%`D$.#(<#00X0A@1!
M#A2#!4X.,&<*#A1""T$.-$$..$$./$$.0$@.,$<./$$.0&<.1$<.2$$.3$$.
M4%0.%$'##A!!Q@X,0<<."$'%#@1%#C"#!84"A@2'`T,.%$'##A!!Q@X,0<<.
M"$'%#@1\`P``^`4``#Z<__^S!0```$$."(4"1@X,AP-!#A"&!$$.%(,%40[`
M@@("C0H.S(("00[0@@)6"VX.S(("00[0@@)(#L""`E$.S(("00[0@@)4#L""
M`E(.Q(("0@[(@@)!#LR"`D4.T(("2P[`@@)P#LR"`D$.T(("2`[`@@)O#LR"
M`D$.T(("2`[`@@),#LR"`D$.T(("8P[,@@)'#LB"`D$.S(("00[0@@)+#M2"
M`D<.V(("00[<@@)$#N""`D@.R(("10[,@@)$#M""`D@.P(("4@[,@@)!#M""
M`D0.U(("1@[8@@)'#MR"`D@.X(("2`[`@@)##L2"`D$.R(("10[,@@)$#M""
M`D@.P(("2@[$@@)&#LB"`D<.S(("2`[0@@)(#L""`GP.S(("00[0@@)7#L""
M`DT.Q(("00[(@@)!#LR"`D8.T(("2`[`@@))#LR"`D$.T(("2`[`@@).#L2"
M`D$.R(("00[,@@)%#M""`D@.P(("7@[,@@)!#M""`D@.P(("2@[$@@)!#LB"
M`D<.S(("00[0@@)(#L""`E8*#L2"`D$.R(("0@[,@@)!#M""`D@.P(("3`[$
M@@)"#LB"`D(.S(("00[0@@)(#L2"`D(.R(("2`[,@@)!#M""`D@.P(("?@[$
M@@)"#LB"`D(.S(("00[0@@)(#L2"`D(.R(("00[,@@)!#M""`DP.S(("00[(
M@@)!#LR"`D$.T(("1`[4@@)%"T(.Q(("0@[(@@)"#LR"`D$.T(("3P[`@@)!
M#L2"`D4.R(("2`[,@@)%#M""`D@.P(("20[$@@)!#LB"`D$.S(("00[0@@)'
M#L""`D,.S(("00[0@@)&#LR"`D$.R(("00[,@@)(#M""`D@.P(("1P[$@@)%
M#LB"`D4.S(("3@[0@@)(#L""`E@.Q(("00[(@@)!#LR"`D<.T(("00[4@@)*
M#MB"`D$.W(("1`[@@@)(#L""`F(.Q(("00[(@@)'#LR"`D$.T(("2@[4@@)$
M#MB"`D$.W(("1`[@@@)(#L""`D$.Q(("00[(@@)%#LR"`D0.T(("2`[`@@)4
M#L2"`D$.R(("00[,@@)!#M""`D0.U(("1`[8@@)!#MR"`D0.X(("2`[`@@)%
M#LR"`D0.T(("50[,@@)$#M""`D@.P(("7@X40<,.$$'&#@Q!QPX(0<4.!```
M`!P!``!X"0``<9[__PH"````00X(A0)!#@R'`T$.$(8$00X4@P5.#BQ(#C!&
M#BQ"#C!;#B!7#BQ"#C!-#C1"#CA!#CQ!#D!(#B!,#BQ$#C!(#B1'#BA!#BQ!
M#C!+#B!+#BQ"#C!&#BQ!#BA!#BQ!#C!(#B!##BQ"#C!-#C1"#CA!#CQ!#D!(
M#B!M"@XL1`XP2`XD00XH00XL00XP3PM-#BQ"#C!(#B1!#BA!#BQ!#C!(#B!#
M"@XL0@XP2`XD2`XH00XL00XP1@XL0@XP2@XD1PXH00XL00XP1@XL0@XP5PX@
M30XL1@XP2`X@30XL2`M!#B1!#BA%#BQ&#C!(#B!.#B1,#BA"#BQ'#C!%#B!#
M#A1!PPX00<8.#$''#@A!Q0X$`%````"8"@``6Y___UX`````00X(AP)!#@R&
M`T$.$(,$4@X<00X@4`X050X400X81PX<00X@2`X010K##@Q#Q@X(0<<.!$4+
M0<,.#$'&#@A!QPX$`$0```#L"@``H(C__]4!````1`P!`$P0!0)U`$(0!P)U
M?!`&`G5X0Q`#`G5T3`\#=7`&`ZP!P0P!`$'#0<9!QT'%0PP$!````#P````T
M"P``'9___[D+````00X(A0)##@R'`T$.$(8$00X4@P5&#I`#`Z@+#A1!PPX0
M0<8.#$''#@A!Q0X$```@````=`L``):J__]2`````$$."(,"3@X<0@X@?PX(
M0<,.!``X````F`L``,2J___Z`````$$."(4"00X,AP-!#A"&!$$.%(,%0PXP
M`NX.%$'##A!!Q@X,0<<."$'%#@1`````U`L``(*K__\F`0```$L."(4"00X,
MAP-!#A"&!$$.%(,%0PXP`H0./`*`#D!,#A1!PPX00<8.#$''#@A!Q0X$`!``
M```8#```9*S__P0`````````'````"P,``!4K/__&0````!!#@B#`DX.$$@.
M"$'##@0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_____P````#_____
M``````$````4`P```0```!\#```/````1P0```P`````$```#0```!$Y``#U
M_O]O]`$```4```#,"```!@```,P"```*````900```L````0````%0``````
M```#````W)X```(```"X`0``%````!$````7````Y`T``!$````T#0``$@``
M`+`````3````"````!@`````````^___;P$```CZ__]O"@``````````````
M```````````````````````````````````````````,G@`````````````V
M$```1A```%80``!F$```=A```(80``"6$```IA```+80``#&$```UA```.80
M``#V$```!A$``!81```F$0``-A$``$81``!6$0``9A$``'81``"&$0``EA$`
M`*81``"V$0``QA$``-81``#F$0``]A$```82```6$@``)A(``#82``!&$@``
M5A(``&82``!V$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(``/82```&
M$P``%A,``"83```V$P``1A,``%83``!F$P``=A,``(83``"6$P``P!,`````
M````````$3D`````````$```````````````````````````````````````
M`````````````*```.)```#;0```'D(``/A````F0@```````/____^V0@``
M1T-#.B`H06QP:6YE(#$Q+C(N,5]G:70R,#(R,#(Q.2D@,3$N,BXQ(#(P,C(P
M,C$Y```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI
M=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`
M+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````````"P````$````"````M`$``+0!```7```````````````!````````
M`!,````'`````@```,P!``#,`0``*```````````````!``````````F````
M]O__;P(```#T`0``]`$``-@````$``````````0````$````,`````L````"
M````S`(``,P"````!@``!0````$````$````$````#@````#`````@```,P(
M``#,"```900``````````````0````````!`````"0````(````T#0``-`T`
M`+`````$``````````0````(````20````D```!"````Y`T``.0-``"X`0``
M!````!,````$````"````%(````!````!@`````0````$```$0``````````
M`````0````````!-`````0````8````@$```(!```(`#`````````````!``
M```$````6`````$````&````H!,``*`3```8```````````````(````"```
M`&$````!````!@```,`3``#`$P``424`````````````$`````````!G````
M`0````8````1.0``$3D```P```````````````$`````````;0````$````"
M`````$````!````Z/P`````````````$`````````'4````!`````@```#Q_
M```\?P``]```````````````!`````````"#`````0````(````P@```,(``
M`$P,``````````````0`````````C0````$````#````_)T``/R-```(````
M```````````$`````````)0````!`````P````2>```$C@``"```````````
M````!`````````";````!@````,````,G@``#(X``-`````%``````````0`
M```(````7`````$````#````W)X``-R.```D`0`````````````$````!```
M`*0````!`````P````"@````D```)```````````````!`````````"J````
M"`````,```!`H```))```#`0`````````````"``````````KP````$````P
M`````````"20```Q```````````````!`````0````$````#````````````
:``!5D```N````````````````0``````````
